    	cd /apoplast/structures/modules/apoplast/data_nodes/ingredients/_mongo_exports/cautionary_ingredients
    	mongoexport --uri "mongodb://localhost:39000/ingredients" --collection cautionary_ingredients --out cautionary_ingredients.1.json

    	cd /apoplast/structures/modules/apoplast/data_nodes/ingredients/_mongo_exports/essential_nutrients
    	mongoexport --uri "mongodb://localhost:39000/ingredients" --collection essential_nutrients --out essential_nutrients.1.json